@@ -41,7 +41,7 @@ def set_dataframe_columntypes(df):
     if 'idCampaign' in df:
         df['idCampaign'] = df['idCampaign'].astype('int8')
     if 'BulkStatus' in df:
-        df['BulkStatus'] = df['BulkStatus'].astype('object')
+        df['BulkStatus']=df['BulkStatus'].astype('str')
     if 'campaign_bulk_date' in df:
         df['campaign_bulk_date'] = df['campaign_bulk_date'].astype('object')
         df['campaign_bulk_date'] = pd.to_datetime(df['campaign_bulk_date'])
